
.. _`MOF compiler API`:

MOF compiler API
================

.. automodule:: pywbem.mof_compiler

.. _`MOFCompiler Class`:

MOFCompiler Class
-----------------

.. autoclass:: pywbem.MOFCompiler
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.MOFCompiler
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.MOFCompiler
      :attributes:

   .. rubric:: Details

.. _`Repository connections`:

Repository connections
----------------------

.. autoclass:: pywbem.BaseRepositoryConnection
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.BaseRepositoryConnection
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.BaseRepositoryConnection
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.MOFWBEMConnection
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.MOFWBEMConnection
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.MOFWBEMConnection
      :attributes:

   .. rubric:: Details

.. _`MOF compiler exceptions`:

Exceptions
----------

The MOF compiler API may raise the exceptions that can be raised by the
:ref:`WBEM client library API`, and in addition the
:exc:`~pywbem.MOFParseError` exception.

.. autoclass:: pywbem.MOFParseError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.MOFParseError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.MOFParseError
      :attributes:

   .. rubric:: Details
